[kaffe] CVS kaffe (guilhem): Fix to be able to compile with ECJ.

Kaffe CVS cvs-commits at kaffe.org
Mon Dec 5 13:00:59 PST 2005


PatchSet 6987 
Date: 2005/12/05 20:53:59
Author: guilhem
Branch: HEAD
Tag: (none) 
Log:
Fix to be able to compile with ECJ.

        * kaffe/scripts/kaffe.in: Use jredir instead of prefix as home
        directory (this is the default for JDK1.2+)

        * kaffe/kaffevm/findInJar.c
        (discoverClasspath): Use ${KAFFEHOME}/lib/rt.jar as main classpath
        now.

        * kaffe/kaffevm/locks.c
        (getHeavyLock): Initialize hlockHolder

Members: 
	ChangeLog:1.4508->1.4509 
	kaffe/kaffevm/findInJar.c:1.70->1.71 
	kaffe/kaffevm/locks.c:1.65->1.66 
	kaffe/scripts/kaffe.in:1.36->1.37 

Index: kaffe/ChangeLog
diff -u kaffe/ChangeLog:1.4508 kaffe/ChangeLog:1.4509
--- kaffe/ChangeLog:1.4508	Sun Dec  4 22:52:18 2005
+++ kaffe/ChangeLog	Mon Dec  5 20:53:59 2005
@@ -1,3 +1,15 @@
+2005-12-05  Guilhem Lavaux  <guilhem at kaffe.org>
+
+	* kaffe/scripts/kaffe.in: Use jredir instead of prefix as home
+	directory (this is the default for JDK1.2+)
+
+	* kaffe/kaffevm/findInJar.c
+	(discoverClasspath): Use ${KAFFEHOME}/lib/rt.jar as main classpath
+	now.
+
+	* kaffe/kaffevm/locks.c
+	(getHeavyLock): Initialize hlockHolder
+	
 2005-12-04  Dalibor Topic  <robilad at kaffe.org>
 
 	* configure.ac: Set compiler to jikes,
Index: kaffe/kaffe/kaffevm/locks.c
diff -u kaffe/kaffe/kaffevm/locks.c:1.65 kaffe/kaffe/kaffevm/locks.c:1.66
--- kaffe/kaffe/kaffevm/locks.c:1.65	Sat Aug 13 23:37:19 2005
+++ kaffe/kaffe/kaffevm/locks.c	Mon Dec  5 20:54:04 2005
@@ -109,6 +109,7 @@
 		  while (!COMPARE_AND_EXCHANGE(lkp, lk, (iLock *)(((uintp)heavyLock) | 1)))
 		    lk = *lkp;
 		  
+		  heavyLock->hlockHolder = KTHREAD(current)();
 		  /* Remind the holder. */
 		  heavyLock->holder = lk;
 		  if (lk != LOCKFREE)
Index: kaffe/kaffe/scripts/kaffe.in
diff -u kaffe/kaffe/scripts/kaffe.in:1.36 kaffe/kaffe/scripts/kaffe.in:1.37
--- kaffe/kaffe/scripts/kaffe.in:1.36	Wed Oct 19 20:10:36 2005
+++ kaffe/kaffe/scripts/kaffe.in	Mon Dec  5 20:54:03 2005
@@ -55,7 +55,7 @@
 fi
 
 if test x"${KAFFEHOME+set}"x != x"set"x; then
-  KAFFEHOME="@prefix@"
+  KAFFEHOME="@jredir@"
 fi
 export KAFFEHOME
 




More information about the kaffe mailing list
Index: kaffe/kaffe/kaffevm/findInJar.c
diff -u kaffe/kaffe/kaffevm/findInJar.c:1.70 kaffe/kaffe/kaffevm/findInJar.c:1.71
--- kaffe/kaffe/kaffevm/findInJar.c:1.70	Mon Oct  3 19:36:00 2005
+++ kaffe/kaffe/kaffevm/findInJar.c	Mon Dec  5 20:54:04 2005
@@ -48,7 +48,7 @@
    in a ClassLoader.  */
 #define HANDLE_MANIFEST_CLASSPATH	1
 
-#define KLASSES_JAR	"Klasses.jar"
+#define KLASSES_JAR	"rt.jar"
 
 classpathEntry* classpath;
 
@@ -475,10 +475,10 @@
 		return;
 	}
 
 	/* Add '.' and <home>/Klasses.jar at the beginning */
 	addClasspath(".");
-	buf = KMALLOC(strlen(home) + strlen(KLASSES_JAR) + 2);
-	sprintf(buf, "%s/%s", home, KLASSES_JAR);
+	buf = KMALLOC(strlen(home) + strlen(KLASSES_JAR) + 6);
+	sprintf(buf, "%s/lib/%s", home, KLASSES_JAR);
 	addClasspath(buf);
 	KFREE(buf);
 
@@ -475,10 +475,10 @@
 	}
 
-	/* Add '.' and <home>/Klasses.jar at the beginning */
+	/* Add '.' and <home>/lib/rt.jar at the beginning */
 	addClasspath(".");